//
// Copyright © 2024 MediaMall Technologies, Inc.  All rights reserved.
//

#ifndef YCSErrors_h
#define YCSErrors_h

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

/// Error domain used for errors reported by the SDK.
extern NSString *const YCSErrorDomain;

/// Error codes reported by the SDK.
typedef NS_ENUM(NSInteger, YCSError)
{
    /// An unknown error occurred.
    YCSErrorUnknown = -10000,

    /// The current version of the SDK is no longer supported.
    YCSErrorSDKVersionNotSupported = -10001,

    /// The system is currently down for maintenance.
    YCSErrorSystemMaintenance = -10002,

    /// A network error occured. The user is either offline or the server returned an invalid response. The specific http status code is available in the statusCode property of the userInfo dictionary.
    YCSErrorNetworkRequestFailed = -10003,

    /// The requested operation has been canceled.
    YCSErrorOperationCanceled = -10004,


    /// The service fetch operation failed.
    YCSErrorServiceFetchingFailed = -20000,

    /// The service linking operation failed.
    YCSErrorServiceLinkingFailed = -20001,

    /// The service is not supported by the SDK.
    YCSErrorServiceUnsupported = -20002,

    /// The service is temporarily unavailable.
    YCSErrorServiceTemporarilyUnavailable = -20003,

    /// The service login failed. The user should verify their login information.
    YCSErrorServiceLoginFailed = -20004,

    /// The service profile was not found. The user should select another profile.
    YCSErrorServiceProfileNotFound = -20005,

    /// The service profile pin was not correct. The user should enter their pin again.
    YCSErrorServiceProfilePinMismatch = -20006,

    /// This service content may no longer be available
    YCSErrorServiceContentNotFound = -20007,


    /// The root window in the view heirarchy was not found.
    YCSErrorRootWindowMissing = -30000
};

NS_ASSUME_NONNULL_END

#endif /* YCSErrors_h */
